@@ -267,13 +267,17 @@ class PhreeqPython(object):
 
         extraneous = {}
 
+        def merge_extraneous(n, extraneous, fraction):
+            for k, v in n.items():
+                if isinstance(v, dict):
+                    extraneous[k] = {} if k not in extraneous else extraneous[k]
+                    merge_extraneous(v, extraneous[k], fraction)
+                else:
+                    extraneous[k] = extraneous.get(k, 0) + v * fraction
+
         for solution, fraction in solutions.items():
 
-            for e,v in solution.extraneous.items():
-                if e in extraneous:
-                    extraneous[e] += v * fraction
-                else:
-                    extraneous[e] = v * fraction
+            merge_extraneous(solution.extraneous, extraneous, fraction)
 
             if isinstance(solution, Solution):
                 pp_ids.add(solution.pp.ip.id_)
